@@ -10,4 +10,4 @@ from ..utils import pool_util
 from ..utils import str_util
 from ..utils import support
 
-__all__ = ['support', 'func_util', 'os_util', 'str_util', 'pool_util', 'list_util', 'file_util']
+__all__ = ['support', 'func_util', 'os_util', 'str_util', 'pool_util', 'list_util', 'file_util','time_util']
